@@ -128,11 +128,11 @@ class _ApplicationApi(_ApiSupport):
         if application_filter is None:
             application_filter = ApplicationFilter()
         path = '{org_uuid}/applications/filter'.format(org_uuid=org_uuid)
-        return self._post(path, params=application_filter.get_params_as_json())
+        return self._get(path, params=application_filter.get_params_as_json())
 
     def get_application_filters(self, org_uuid):
         path = '{org_uuid}/applications/filters/listing'.format(org_uuid=org_uuid)
-        return self._post(path)
+        return self._get(path)
 
     def get_application(self, org_uuid, app_id, expand=None, include_merged=True):
         path = '{org_uuid}/applications/{app_id}'.format(org_uuid=org_uuid, app_id=app_id)
@@ -151,7 +151,7 @@ class _ApplicationApi(_ApiSupport):
         if application_trace_filter is None:
             application_trace_filter = ApplicationTraceFilter()
         path = '{org_uuid}/traces/{app_id}/filter'.format(org_uuid=org_uuid, app_id=app_id)
-        return self._post(path, params=application_trace_filter.get_params_as_json())
+        return self._get(path, params=application_trace_filter.get_params_as_json())
 
     def get_application_vuln_details(self, org_uuid, app_id, trace_uuid, expand=None):
         path = '{org_uuid}/traces/{app_id}/filter/{trace_uuid}'.format(org_uuid=org_uuid, app_id=app_id, trace_uuid=trace_uuid)
