@@ -8,4 +8,5 @@ class _SessionMetadataApi(_ApiSupport):
 
     def filter_app_session_metadata(self, org_uuid, app_id):
         path = '{org_uuid}/metadata/session/{app_id}/filters'.format(org_uuid=org_uuid, app_id=app_id)
-        return self._post(path)
+        no_filter = {}
+        return self._post(path,data=no_filter)
